@@ -1,7 +1,8 @@
 """This module contains the input model for the chp system."""
 from pysimmods.model.inputs import ModelInputs
-from pysimmods.generator.chplpgsim.inputs import CHPLPGInputs
-from pysimmods.other.heatdemandsim.inputs import HeatDemandInputs
+
+# from pysimmods.generator.chplpgsim.inputs import CHPLPGInputs
+# from pysimmods.other.heatdemandsim.inputs import HeatDemandInputs
 
 
 class CHPLPGSystemInputs(ModelInputs):
@@ -12,3 +13,5 @@ class CHPLPGSystemInputs(ModelInputs):
 
         self.day_avg_t_air_deg_celsius = None
         """Average temperature of the current day in [°C]."""
+
+        self.e_th_demand_set_kwh = None
