@@ -4,6 +4,7 @@ pysimmods package.
 
 """
 from __future__ import annotations
+import json
 
 import sys
 from datetime import datetime, timedelta, timezone
@@ -266,7 +267,7 @@ class FlexibilitySimulator(PysimmodsSimulator):
 
                 elif attr == "schedule":
                     value = self._get_attr_schedule(eid)
-                    log_msg[attr] = value
+                    log_msg[attr] = json.loads(value)
 
                 else:
                     value = self._get_remaining_attrs(eid, attr)
@@ -275,7 +276,7 @@ class FlexibilitySimulator(PysimmodsSimulator):
                 data.setdefault(eid, dict())[attr] = value
 
             if self.key_value_logs:
-                LOG.info(log_msg)
+                LOG.info(json.dumps(log_msg))
 
         if not self.key_value_logs:
             LOG.debug("Gathered outputs: %s.", data)
